@@ -1,5 +1,3 @@
-context("comparing vis")
-
 # make a new dataset of iris that contains some NA values
 
 iris_diff <- iris
@@ -9,6 +7,7 @@ vis_compare_plot <- vis_compare(iris, iris_diff)
 
 test_that("vis_compare works",{
   skip_on_cran()
+  skip_on_ci()
 vdiffr::expect_doppelganger("vis_compare vanilla", vis_compare_plot)
 })
 
@@ -16,12 +15,23 @@ iris_add <- iris
 iris_add$extra <- 1
 
 test_that("vis_compare will not accept two dataframes of differing dims",{
-  expect_error(
-    vis_compare(iris, iris_add))
+  expect_snapshot(
+    error = TRUE,
+    vis_compare(iris, iris_add)
+    )
 })
 
 test_that("vis_compare fails when an object of the wrong class is provided", {
-  testthat::expect_error(vis_compare(iris, AirPassengers))
-  testthat::expect_error(vis_compare(AirPassengers, iris))
-  testthat::expect_error(vis_compare(AirPassengers, AirPassengers))
+  expect_snapshot(
+    error = TRUE,
+    vis_compare(iris, AirPassengers)
+    )
+  expect_snapshot(
+    error = TRUE,
+    vis_compare(AirPassengers, iris)
+    )
+  expect_snapshot(
+    error = TRUE,
+    vis_compare(AirPassengers, AirPassengers)
+    )
 })
