@@ -1,7 +1,3 @@
-context("Test names with spaces")
-
-library(visdat)
-
 messy_names <- tibble::tibble(`Sepal Width` = iris$Sepal.Width,
                               `Sepal Length` = iris$Sepal.Length,
                               `Petal Length` = iris$Petal.Length,
@@ -9,5 +5,5 @@ messy_names <- tibble::tibble(`Sepal Width` = iris$Sepal.Width,
 
 
 test_that("vis_dat works on dataframes with irregular variable names", {
-  expect_is(vis_dat(messy_names), "ggplot")
+  expect_s3_class(vis_dat(messy_names), "gg")
 })
